// ============ Infrarot-Fernbedienung =============

/*
  IRremote: IRrecvDemo - demonstrates
  receiving IR codes with IRrecv
  An IR detector/demodulator must be
  connected to the input RECV_PIN.
  Version 0.1 July, 2009
  Copyright 2009 Ken Shirriff
  http://arcfn.com
*/
//Infromationen über das ursprüngliche Programm „IrrecvDemo“.

// Library als Zip-Datei herunterladen und installieren!
// https://downloads.arduino.cc/libraries/github.com/z3t0/IRremote-2.2.3.zip

#include <IRremote.h>   // Das Programm greift an dieser Stelle auf eine „Library“ zurück. Das erleichtert einem viel Arbeit. Denn das Infrarotlicht wird mit einem Code verschlüsselt gesendet. Um diesen Code selber auszulesen und in passende Werte umzuwandeln, wären sehr viele Zeilen Code erforderlich.

int RECV_PIN = 11;  //  Der Kontakt der am Infrarotsensor die Daten ausgibt, wird mit Pin 11 des Arduinoboards verbunden.

IRrecv irrecv(RECV_PIN);   // An dieser Stelle wird ein Objekt definiert, dass den Infrarotsensor an Pin 11 ausliest.

decode_results results;  // Dieser Befehl sorgt dafür, dass die Daten, die per Infrarot eingelesen werden unter „results“ abgespeichert werden.

// ======== Display ==============

#include <Wire.h> // Wire Bibliothek einbinden
#include <LiquidCrystal_I2C.h>

LiquidCrystal_I2C lcd(0x3F, 16, 2);

void setup() {
  Serial.begin(9600);    //Im Setup wird die Serielle Verbindung gestartet, damit man sich die Empfangenen Daten der Fernbedienung per seriellen Monitor ansehen kann.

  pinMode (13, OUTPUT);

  irrecv.enableIRIn();   //Dieser Befehl initialisiert den Infrarotempfänger.

  // LCD
  lcd.init(); // LCD gestartet
  lcd.backlight();
}

void loop() { //Der loop-Teil fällt durch den Rückgriff auf die „library“ sehr kurz aus.
  if (irrecv.decode(&results)) {    //Wenn Daten empfangen wurden,
    // die Ausgabewerte wieder in Buchstaben/Zahlen übersetzen,
    // die man auf der Fernbedienung gedrückt hat
    wertUebersetzen();
    delay(1500); // erkannte Taste soll 1,5sek auf Display angezeigt werden
    lcd_Clearing();

    irrecv.resume();  //Der nächste Wert soll vom IR-Empfänger eingelesen werden
  } else {

    // wenn nichts erkannt wird, erscheint diese Aufforderung auf dem Display
    lcd.setCursor(0, 0); // 1. Zeile
    lcd.print("Taste druecken!");

    // LED ausschalten
    digitalWrite(13, LOW);
  }
}

// ACHTUNG, Werte von "meiner" Fernbedienung
// kann bei Euch anders sein – im Serial Monitor bitte selber auslesen!
void wertUebersetzen() {
  lcd_Clearing();

  // Ausgabe auf das Display
  lcd.setCursor(0, 0); // 1. Zeile
  lcd.print("gedrueckte Taste:");

  // hier nur die 'Single Quotes' verwenden, sonst geht es nicht!
  if (results.value == 16738455) {
    zeile2Ausgabe('1');
  } else if (results.value == 16750695) {
    zeile2Ausgabe('2');
  } else if (results.value == 16756815) {
    zeile2Ausgabe('3');
  } else if (results.value == 16724175) {
    zeile2Ausgabe('4');
  } else if (results.value == 16718055) {
    zeile2Ausgabe('5');
  } else if (results.value == 16753245) {
    zeile2Ausgabe('A');

    // LED anschalten
    digitalWrite(13, HIGH);
  }
}

// in beiden Zeilen 16 Leerzeichen schreiben, damit keine Artefakte zurückbleiben!
// Display hat 16 Stellen pro Zeile
void lcd_Clearing() {
  lcd.setCursor(0, 0); // 1. Zeile
  lcd.print("                ");

  lcd.setCursor(0, 1); // 2. Zeile
  lcd.print("                ");
}

void zeile2Ausgabe(char glyph) {
  lcd.setCursor(0, 1); // 2. Zeile
  lcd.print(glyph);
}
